@@ -2,7 +2,7 @@
  * File        : io.h
  * Author      : Stuart Menefy
  * Description : Interface to IO routines
- * Header      : $Id: io.h,v 1.2 1994/02/08 11:34:38 stuart Exp $
+ * Header      : $Id: io.h,v 1.3 1994/05/10 14:46:24 stuart Exp $
  *
  * This file defines the interface which is required by cmonitor.c to
  * access the file system and terminal.
@@ -20,7 +20,7 @@ void print_int(int num);
 char getchar(void);
 
 /* Disk/file I/O functions (diskio.c or linkio.c). */
-void disk_init(void);
+int disk_init(void);
 void r_open(const char* filename);
 int r_read(char* buffer);
 void r_close(void);
